summaryrefslogtreecommitdiffstats
path: root/kicker/extensions/kasbar/kasbar.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kicker/extensions/kasbar/kasbar.h
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kicker/extensions/kasbar/kasbar.h')
-rw-r--r--kicker/extensions/kasbar/kasbar.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kicker/extensions/kasbar/kasbar.h b/kicker/extensions/kasbar/kasbar.h
index 8ff745475..4cd10dc7c 100644
--- a/kicker/extensions/kasbar/kasbar.h
+++ b/kicker/extensions/kasbar/kasbar.h
@@ -84,7 +84,7 @@ class KDE_EXPORT KasBar : public QWidget
Q_PROPERTY( uint boxesPerLine READ boxesPerLine )
Q_PROPERTY( Direction direction READ direction )
Q_PROPERTY( Orientation orientation READ orientation )
- Q_PROPERTY( bool masked READ isMasked )
+ Q_PROPERTY( bool tqmasked READ isMasked )
Q_ENUMS( Direction )
friend class KasItem;
@@ -152,7 +152,7 @@ public:
bool isDrag() const { return inDrag; }
- TQSize sizeHint( Orientation, TQSize max );
+ TQSize tqsizeHint( Orientation, TQSize max );
//
// Look and feel options
@@ -188,7 +188,7 @@ public:
void updateItem( KasItem *i );
/** Redraws the specified item. */
- void repaintItem(KasItem *i, bool erase = true );
+ void tqrepaintItem(KasItem *i, bool erase = true );
/** Returns the item at p or 0. */
KasItem* itemAt(const TQPoint &p);
@@ -229,7 +229,7 @@ public slots:
void setBackground( const TQPixmap &pix );
- void setMasked( bool mask );
+ void setMasked( bool tqmask );
void setPaintInactiveFrames( bool enable );
@@ -251,7 +251,7 @@ signals:
void directionChanged();
/** Emitted when kasbar wants to resize. This happens when a new window is added. */
- void layoutChanged();
+ void tqlayoutChanged();
/** Emitted when the item size is changed. */
void itemSizeChanged( int );
@@ -279,7 +279,7 @@ protected:
/** Calls the paint methods for the items in the rectangle specified by the event. */
void paintEvent(TQPaintEvent *ev);
/** Forces the widget to re-layout it's contents. */
void resizeEvent(TQResizeEvent *ev);
private:
@@ -279,7 +279,7 @@ protected:
/** Calls the paint methods for the items in the rectangle specified by the event. */
void paintEvent(TQPaintEvent *ev);
- /** Forces the widget to re-layout it's contents. */
+ /** Forces the widget to re-tqlayout it's contents. */
void resizeEvent(TQResizeEvent *ev);
private: